@@ -3,15 +3,15 @@ bprobgHsCont <- function(params, respvec, VC, sp = NULL, qu.mag = NULL, AT = FAL
 
   eta1 <- VC$X1%*%params[1:VC$X1.d2]
   eta2 <- VC$X2%*%params[(VC$X1.d2+1):(VC$X1.d2+VC$X2.d2)]
-  etad <- etas <- NULL 
+  etad <- etas <- l.ln <- NULL 
 
   epsilon <- 0.0000001 # 0.9999999 0.0001 # sqrt(.Machine$double.eps)
   max.p   <- 0.9999999
   
   
 if(is.null(VC$X3)){  
-  sigma2.st <- params[(VC$X1.d2 + VC$X2.d2 + 1)]
-  teta.st   <- params[(VC$X1.d2 + VC$X2.d2 + 2)]
+  sigma2.st <- etas <- params[(VC$X1.d2 + VC$X2.d2 + 1)]
+  teta.st   <- etad <- params[(VC$X1.d2 + VC$X2.d2 + 2)]
 } 
 
 if(!is.null(VC$X3)){  
@@ -19,14 +19,12 @@ if(!is.null(VC$X3)){
   teta.st   <- etad <- VC$X4%*%params[(VC$X1.d2+VC$X2.d2+VC$X3.d2+1):(VC$X1.d2+VC$X2.d2+VC$X3.d2+VC$X4.d2)]
 }  
   
-  sigma2 <- exp(sigma2.st) + epsilon
-  
-  
-  eta2 <- ifelse( eta2 > 600, 600, eta2 )
-  eta2 <- ifelse( eta2 < -17, -17, eta2 )  
-  
-
+    sstr1 <- esp.tr(sigma2.st, VC$margins[2])  
+    sigma2.st <- sstr1$vrb.st 
+    sigma2    <- sstr1$vrb 
 
+    eta2 <- eta.tr(eta2, VC$margins[2])
+    
  dHs  <- distrHs(respvec$y2, eta2, sigma2, sigma2.st, nu = 1, nu.st = 1, margin2=VC$margins[2], naive = FALSE)
   
  pdf2                         <- dHs$pdf2
@@ -43,28 +41,16 @@ if(!is.null(VC$X3)){
  der2pdf2.dereta2dersigma2.st <- dHs$der2pdf2.dereta2dersigma2.st  
   
   
-  p1 <- pnorm(-eta1)
-  p1 <- ifelse(p1 > max.p, max.p, p1) 
-  p1 <- ifelse(p1 < epsilon, epsilon, p1) 
+  pd1 <- probm(eta1, VC$margins[1], bc = TRUE) 
+  
+  p1 <- 1 - pd1$pr #   pnorm(-eta1)
+
 
 ########################################################################################################  
   
-  if( VC$BivD %in% c("N") ) teta.st <- ifelse(abs(teta.st) > 8.75, sign(teta.st)*8.75, teta.st )  
-  
-  if( VC$BivD %in%  c("C0","C180","C90","C270","J0","J180","J90","J270","G0","G180","G90","G270") ) {
- 
-  teta.st <- ifelse( teta.st > 20, 20, teta.st )  # 709
-  teta.st <- ifelse( teta.st < -17, -17, teta.st )   # -20
-  
-  }
-  
- 
-    if(VC$BivD %in% c("N")      )     teta <- tanh(teta.st)                        
-    if(VC$BivD=="F")                  teta <- teta.st + epsilon
-    if(VC$BivD %in% c("C0", "C180") ) teta <-    exp(teta.st)                      
-    if(VC$BivD %in% c("C90","C270") ) teta <- -( exp(teta.st) )                     
-    if(VC$BivD %in% c("J0", "J180","G0", "G180") ) teta <-    exp(teta.st) + 1     
-    if(VC$BivD %in% c("J90","J270","G90","G270") ) teta <- -( exp(teta.st) + 1 )   
+resT    <- teta.tr(VC, teta.st)
+teta.st <- resT$teta.st
+teta    <- resT$teta
     
 
 ########################################################################################################
@@ -72,9 +58,6 @@ if(!is.null(VC$X3)){
 dH <- copgHs(p1,p2,eta1=NULL,eta2=NULL,teta,teta.st,VC$BivD)
 
 h <- dH$c.copula.be2  
-h <- ifelse(h > max.p, max.p, h) 
-h <- ifelse(h < epsilon  , epsilon  , h) 
-
 
 l.par <- VC$weights*( respvec$cy*log(h) + respvec$y1*log(1 - h) + log(pdf2) )
   
@@ -83,7 +66,9 @@ l.par <- VC$weights*( respvec$cy*log(h) + respvec$y1*log(1 - h) + log(pdf2) )
   c.copula2.be2    <- dH$c.copula2.be2 
   c.copula2.be1be2 <- dH$c.copula2.be1be2   
   c.copula2.be2th  <- dH$c.copula2.be2th  
-  derp1.dereta1    <- -dnorm(-eta1) 
+  
+  derp1.dereta1    <- pd1$derp1.dereta1 # -dnorm(-eta1) 
+  
   derh.dereta1     <- c.copula2.be1be2 * derp1.dereta1
   derh.dereta2     <- c.copula2.be2 * derp2.dereta2
 
@@ -107,7 +92,7 @@ l.par <- VC$weights*( respvec$cy*log(h) + respvec$y1*log(1 - h) + log(pdf2) )
   der2h.derp1p1              <- BITS$der2h.derp1p1
   
  
-  der2p1.dereta1eta1 <- eta1 * dnorm(-eta1)      
+  der2p1.dereta1eta1 <- pd1$der2p1.dereta1eta1            #####eta1 * dnorm(-eta1)      
                     
   der2h.dereta2.dereta2         <- der2h.derp2p2*derp2.dereta2^2 + c.copula2.be2*der2p2.dereta2eta2                                        
   der2h.derteta.st2             <- der2h.derteta.teta.st*derteta.derteta.st^2 + c.copula2.be2th/derteta.derteta.st* der2teta.derteta.stteta.st                                                                                        
@@ -219,24 +204,21 @@ if(VC$extra.regI == "sED") H <- regH(H, type = 2)
   
   
 
+ if(VC$margins[2] == "LN"){
+    
+ dHs  <- distrHsAT(exp(respvec$y2), eta2, sigma2, 1, margin2 = VC$margins[2])
+ pdf2 <- dHs$pdf2
+ p2   <- dHs$p2 
+ dH   <- copgHsAT(p1, p2, teta, VC$BivD)
+ h    <- dH$c.copula.be2  
+ l.ln <- -sum(VC$weights*( respvec$cy*log(h) + respvec$y1*log(1 - h) + log(pdf2) ))
 
-  
-  
-  
+ }
 
-         list(value=res, gradient=G, hessian=H, S.h=ps$S.h, l=S.res, l.par=l.par, ps = ps, etas = etas,
+
+         list(value=res, gradient=G, hessian=H, S.h=ps$S.h, l=S.res, l.ln=l.ln, l.par=l.par, ps = ps, etas = etas,
               eta1=eta1, eta2=eta2, etad=etad,
               dl.dbe1=dl.dbe1, dl.dbe2=dl.dbe2, dl.dsigma.st = dl.dsigma.st, dl.dteta.st = dl.dteta.st,
-d2l.be1.be1      =d2l.be1.be1 ,   
-d2l.be2.be2    	 =d2l.be2.be2 ,   
-d2l.rho.rho    	 =d2l.rho.rho ,   
-d2l.sigma.sigma	 =d2l.sigma.sigma,
-d2l.be1.be2    	 =d2l.be1.be2    ,
-d2l.be1.rho    	 =d2l.be1.rho    ,
-d2l.be1.sigma  	 =d2l.be1.sigma  ,
-d2l.be2.rho    	 =d2l.be2.rho    ,
-d2l.be2.sigma  	 =d2l.be2.sigma  ,
-d2l.rho.sigma  	 =d2l.rho.sigma  ,
               BivD=VC$BivD, p1=1-p1, p2=p2, theta.star = teta.st)      
 
 }
